//
//	SPI methods.
//
//	Copyright 2014 Mark Stevens
//
#include "spi.h"

//
//	Initialise SPI
//
void InitialiseSPI()
{
	SPI_InitTypeDef SPI_InitStruct;
	//
	// 	Connect SPI1 pins to SPI alternate function.
	//
	GPIO_PinAFConfig(GPIOA, GPIO_PinSource5, GPIO_AF_SPI1);
	GPIO_PinAFConfig(GPIOA, GPIO_PinSource6, GPIO_AF_SPI1);
	GPIO_PinAFConfig(GPIOA, GPIO_PinSource7, GPIO_AF_SPI1);
	//
	//	Set PE6 high as we will be using active low for the
	//	device select.
	//
	GPIOE->BSRRL |= GPIO_Pin_6;
	//
	// 	Enable the SPI peripheral clock.
	//
	RCC_APB2PeriphClockCmd(RCC_APB2Periph_SPI1, ENABLE);

	//
	//	Configure SPI1 in Mode 0:
	//		CPOL = 0 --> clock is low when idle
	//		CPHA = 0 --> data is sampled at the first edge
	//
	//	SPI Master mode, 8 bits of data, clock prescalar is 128, MSB is
	//	transmitted first.
	//
	SPI_InitStruct.SPI_Direction = SPI_Direction_2Lines_FullDuplex;
	SPI_InitStruct.SPI_Mode = SPI_Mode_Master;
	SPI_InitStruct.SPI_DataSize = SPI_DataSize_8b;
	SPI_InitStruct.SPI_CPOL = SPI_CPOL_Low;
	SPI_InitStruct.SPI_CPHA = SPI_CPHA_1Edge;
	SPI_InitStruct.SPI_NSS = SPI_NSS_Soft | SPI_NSSInternalSoft_Set;
	SPI_InitStruct.SPI_BaudRatePrescaler = SPI_BaudRatePrescaler_128;
	SPI_InitStruct.SPI_FirstBit = SPI_FirstBit_MSB;
	SPI_Init(SPI1, &SPI_InitStruct);
	//
	//	Enable SPI.
	//
	SPI_Cmd(SPI1, ENABLE);
}

//
//	Transmit and receive a single byte of data.
//
uint8_t SPISend(uint8_t data)
{
	//
	//	Setting the Data Register (DR) transmits the byte of data on MOSI.
	//
	SPI1->DR = data;
	//
	//	Wait until the data has been transmitted.
	//
	while (!(SPI1->SR & SPI_I2S_FLAG_TXE));
	//
	//	Wait for any data on MISO pin to be received.
	//
	while (!(SPI1->SR & SPI_I2S_FLAG_RXNE));
	//
	//	All data transmitted/received but SPI may be busy so wait until done.
	//
	while (SPI1->SR & SPI_I2S_FLAG_BSY);
	//
	//	Return the data received on MISO pin.
	//
	return(SPI1->DR);
}

